@@ -175,7 +175,9 @@ class MetricsExtractor:
                 "Are you sure you want to delete %s?" % self.tmpdir
             ):
                 return
-            shutil.rmtree(self.tmpdir)
+
+            # GitHub actions appears to have race condition
+            shutil.rmtree(self.tmpdir, ignore_errors=True)
 
     def extract_all(self, versions=None):
         versions = versions or []
